import { Component } from '@angular/core';
import {FormGroup, FormsModule, NonNullableFormBuilder, ReactiveFormsModule, Validators} from "@angular/forms";
import {DictionaryPipe} from "../../../pipes/common/dictionary.pipe";
import {NzMessageService} from "ng-zorro-antd/message";
import {BrowserStorageService} from "../../../utils/localStorage.service";
import {AgentService} from "../../../services/agent/agent.service";
import {CommonService} from "../../../services/common/common.service";
import {NzModalModule, NzModalService} from "ng-zorro-antd/modal";
import {DatePipe, NgForOf, NgIf} from "@angular/common";
import {NzButtonComponent} from "ng-zorro-antd/button";
import {
  NzCellFixedDirective,
  NzTableCellDirective,
  NzTableComponent, NzTableModule,
  NzTbodyComponent, NzTheadComponent,
  NzThMeasureDirective, NzTrDirective
} from "ng-zorro-antd/table";
import {NzColDirective, NzRowDirective} from "ng-zorro-antd/grid";
import {NzDividerComponent} from "ng-zorro-antd/divider";
import {NzDropDownADirective, NzDropDownDirective, NzDropdownMenuComponent} from "ng-zorro-antd/dropdown";
import {NzFormControlComponent, NzFormDirective, NzFormItemComponent, NzFormLabelComponent} from "ng-zorro-antd/form";
import {NzIconDirective} from "ng-zorro-antd/icon";
import {NzInputDirective} from "ng-zorro-antd/input";
import {NzMenuDirective, NzMenuItemComponent} from "ng-zorro-antd/menu";
import {NzOptionComponent, NzSelectComponent} from "ng-zorro-antd/select";
import {NzFlexDirective} from "ng-zorro-antd/flex";
import {NzDescriptionsModule} from "ng-zorro-antd/descriptions";
import {NzUploadComponent} from "ng-zorro-antd/upload";
import {NzAvatarModule} from "ng-zorro-antd/avatar";
import {NzImageModule} from "ng-zorro-antd/image";
import {NzSwitchComponent} from "ng-zorro-antd/switch";
import {NzDatePickerComponent} from "ng-zorro-antd/date-picker";
import {NzInputNumberModule} from "ng-zorro-antd/input-number";
import {AgentMerService} from "../../../services/agent/agent-mer.service";
import {NzTypographyComponent} from "ng-zorro-antd/typography";
import {DATA} from "../../../data/login/localStorage.namespace";
import {AgentStaffService} from "../../../services/agent/agent-staff.service";

@Component({
  selector: 'app-agent-mer-list',
  standalone: true,
  imports: [
    DatePipe,
    DictionaryPipe,
    FormsModule,
    NgForOf,
    NgIf,
    NzButtonComponent,
    NzCellFixedDirective,
    NzColDirective,
    NzDividerComponent,
    NzDropDownADirective,
    NzDropDownDirective,
    NzDropdownMenuComponent,
    NzFormControlComponent,
    NzFormDirective,
    NzFormItemComponent,
    NzFormLabelComponent,
    NzIconDirective,
    NzInputDirective,
    NzMenuDirective,
    NzMenuItemComponent,
    NzOptionComponent,
    NzRowDirective,
    NzSelectComponent,
    NzTableCellDirective,
    NzTableComponent,
    NzTbodyComponent,
    NzThMeasureDirective,
    NzTheadComponent,
    NzTrDirective,
    ReactiveFormsModule,
    NzTableModule,
    NzModalModule,
    NzFlexDirective,
    NzDescriptionsModule,
    NzUploadComponent,
    NzAvatarModule,
    NzImageModule,
    NzSwitchComponent,
    NzDatePickerComponent,
    NzInputNumberModule,
    NzTypographyComponent
  ],
  templateUrl: './agent-mer-list.component.html',
  styleUrl: './agent-mer-list.component.less'
})
export class AgentMerListComponent {
  // 表单页数
  tablePageNum = 1;
  // 每页数量
  tablePageSize = 10;
  // 表单数据
  tableData: any = {
    total: 0,
    list: [],
  };
  // 搜索表单
  searchForm: FormGroup;
  // 登录的账户类型
  accountType = null;
  // 油站来源
  merSourceTypeArray = new DictionaryPipe().getDictionaryList('MER_SOURCE_TYPE');
  // 商户状态
  merStatusArray = new DictionaryPipe().getDictionaryList('MERCHANT_STATUS');
  // 地区数据
  regionData: any = [];
  // 代理数据
  agentData: any = [];
  // 代理工作人员
  agentStaffData: any = [];
  // 列表中全选状态
  checked = false;
  // 已选择的数据
  setOfCheckedId = new Set<string>();
  constructor(private fb: NonNullableFormBuilder,
              private message: NzMessageService,
              private storage: BrowserStorageService,
              private agentService: AgentService,
              private agentStaffService: AgentStaffService,
              private agentMerService: AgentMerService,
              private commonService: CommonService,
              private modal: NzModalService) {

    this.accountType = this.storage.get(DATA)['account']['objectType'];

    // 初始化搜索框
    this.searchForm = this.fb.group({
      agentId: [''],
      agentStaffId: [''],
      isAgentAllot: ['true'],
      isAgentStaffAllot: ['true'],
      provinceCode: [null],
      merSourceType: [null],
      merNo: [null],
      merName: [null],
      status: [null],
    });
    if (this.accountType == 1) {
      // 获取代理商
      this.agentService.queryAgentList({type:'1,2',pageNum:1,pageSize:999}, (data: any) => {
        this.agentData = data['return_data']['list'];
        this.searchForm.controls['agentId'].setValue(String(this.agentData[0]['id']));
        // 查询数据
        this.queryData();
      });

    } else if (this.accountType == 4) {
      // 获取代理商工作人员
      this.agentStaffService.getStaffList({pageNum:1,pageSize:999}, (data: any) => {
        this.agentStaffData = data['return_data']['list'];
        if (this.agentStaffData.length > 0) {
          this.searchForm.controls['agentStaffId'].setValue(String(this.agentStaffData[0]['id']));
          // 查询数据
          this.queryData();
        }
      });
    }

    // 获取地区
    this.commonService.getRegion("", (data: any) => {
      this.regionData = data['return_data'];
    });

  }

  /**
   * 获取数据
   */
  queryData() {
    if (this.accountType == 1) {
      this.searchForm.value.isAgentStaffAllot = false;
    }
    this.searchForm.value.pageNum = this.tablePageNum;
    this.searchForm.value.pageSize = this.tablePageSize;
    this.searchForm.value.time = new Date().getTime();
    this.agentMerService.getAllotList(this.searchForm.value, (data: any) => {
      if (data['return_code'] == '000000') {
        this.tableData = data['return_data'];
      }
    });
  }

  /**
   * 搜索表单提交
   */
  searchFormSubmit(): void {
    this.tablePageNum = 1;
    this.queryData();
  }

  /**
   * 搜索表单重置
   */
  searchFormReset(): void {
    this.searchForm.reset();
  }

  /**
   * 打开分配模态框
   */
  assign() {
    if (this.setOfCheckedId.size == 0) {
      this.modal.warning({
        nzTitle: '提示',
        nzContent: '请在列表中勾选需要分配的油站'
      });
      return;
    }
    this.modal.confirm({
      nzTitle: '提示',
      nzContent: '确定将已勾选的'+this.setOfCheckedId.size+'个油站，分配给代理商吗？',
      nzOnOk: () => this.submitAssign()
    });
  }

  /**
   * 提交数据
   */
  submitAssign() {
    let merNoList = [];
    for (let merNo of this.setOfCheckedId) {
      merNoList.push({merNo: merNo});
    }
    if (this.accountType == 1) {
      const param = {
        agentId: this.searchForm.controls['agentId'].value,
        merNoList: merNoList
      };
      this.agentMerService.assignAgent(param, (data: any) => {
        if (data['return_code'] == '000000') {
          this.message.create('success', '操作成功');
          // 清除已勾选的油站
          this.setOfCheckedId.clear();
          // 刷新数据
          this.queryData();
        } else {
          this.message.create('error', data['return_msg']);
        }
      });
    } else if (this.accountType == 4) {
      const param = {
        staffId: this.searchForm.controls['agentStaffId'].value,
        merNoList: merNoList
      };
      this.agentMerService.assignStaff(param, (data: any) => {
        if (data['return_code'] == '000000') {
          this.message.create('success', '操作成功');
          // 刷新数据
          this.queryData();
        } else {
          this.message.create('error', data['return_msg']);
        }
      });
    }

  }

  /**
   * 打开解绑模态框
   */
  unbind() {
    if (this.setOfCheckedId.size == 0) {
      this.modal.warning({
        nzTitle: '提示',
        nzContent: '请在列表中勾选需要解绑的油站'
      });
      return;
    }
    this.modal.confirm({
      nzTitle: '提示',
      nzContent: '确定将已勾选的'+this.setOfCheckedId.size+'个油站解绑吗？',
      nzOnOk: () => this.submitUnbind()
    });
  }

  /**
   * 提交数据
   */
  submitUnbind() {
    let merNoList = [];
    for (let merNo of this.setOfCheckedId) {
      merNoList.push({merNo: merNo});
    }

    if (this.accountType == 1) {
      const param = {
        agentId: this.searchForm.controls['agentId'].value,
        merNoList: merNoList
      };
      this.agentMerService.unbindAgent(param, (data: any) => {
        if (data['return_code'] == '000000') {
          this.message.create('success', '操作成功');
          // 清除已勾选的油站
          this.setOfCheckedId.clear();
          // 刷新数据
          this.queryData();
        } else {
          this.message.create('error', data['return_msg']);
        }
      });
    } else if (this.accountType == 4) {
      const param = {
        staffId: this.searchForm.controls['agentStaffId'].value,
        merNoList: merNoList
      };
      this.agentMerService.unbindStaff(param, (data: any) => {
        if (data['return_code'] == '000000') {
          this.message.create('success', '操作成功');
          // 刷新数据
          this.queryData();
        } else {
          this.message.create('error', data['return_msg']);
        }
      });
    }
  }

  /**
   * 修改选择状态
   * @param merNo
   * @param checked
   */
  updateCheckedSet(merNo: string, checked: boolean): void {
    if (checked) {
      this.setOfCheckedId.add(merNo);
    } else {
      this.setOfCheckedId.delete(merNo);
    }
  }

  /**
   * 单选
   * @param merNo
   * @param checked
   */
  onItemChecked(merNo: string, checked: boolean): void {
    this.updateCheckedSet(merNo, checked);
    this.refreshCheckedStatus();
  }

  /**
   * 全选
   * @param checked
   */
  onAllChecked(checked: boolean): void {
    // @ts-ignore
    this.tableData.list.forEach(({ merNo }) => this.updateCheckedSet(merNo, checked));
    this.refreshCheckedStatus();
  }

  /**
   * 刷新数据
   */
  refreshCheckedStatus(): void {
    // @ts-ignore
    this.checked = this.tableData.list.every(({ merNo }) => this.setOfCheckedId.has(merNo));
    console.log(this.setOfCheckedId);
  }


}
