import { Component } from '@angular/core';
import {DatePipe, NgForOf, NgIf} from "@angular/common";
import {DictionaryPipe} from "../../../pipes/common/dictionary.pipe";
import {NzButtonComponent} from "ng-zorro-antd/button";
import {
  NzCellFixedDirective,
  NzTableCellDirective,
  NzTableComponent, NzTableModule,
  NzTbodyComponent, NzTheadComponent,
  NzThMeasureDirective, NzTrDirective
} from "ng-zorro-antd/table";
import {NzColDirective, NzRowDirective} from "ng-zorro-antd/grid";
import {NzDropDownADirective, NzDropDownDirective, NzDropdownMenuComponent} from "ng-zorro-antd/dropdown";
import {NzFlexDirective} from "ng-zorro-antd/flex";
import {NzFormControlComponent, NzFormDirective, NzFormItemComponent, NzFormLabelComponent} from "ng-zorro-antd/form";
import {NzIconDirective} from "ng-zorro-antd/icon";
import {NzInputDirective} from "ng-zorro-antd/input";
import {NzMenuDirective, NzMenuItemComponent} from "ng-zorro-antd/menu";
import {NzModalComponent, NzModalModule, NzModalService} from "ng-zorro-antd/modal";
import {NzOptionComponent, NzSelectComponent} from "ng-zorro-antd/select";
import {FormGroup, FormsModule, NonNullableFormBuilder, ReactiveFormsModule, Validators} from "@angular/forms";
import {NzMessageService} from "ng-zorro-antd/message";
import {BrowserStorageService} from "../../../utils/localStorage.service";
import {AgentService} from "../../../services/agent/agent.service";
import {AgentStaffService} from "../../../services/agent/agent-staff.service";
import {CommonService} from "../../../services/common/common.service";
import {NzDividerComponent} from "ng-zorro-antd/divider";
import {NzDescriptionsModule} from "ng-zorro-antd/descriptions";
import {NzUploadComponent} from "ng-zorro-antd/upload";
import {NzAvatarModule} from "ng-zorro-antd/avatar";
import {NzImageModule} from "ng-zorro-antd/image";
import {NzSwitchComponent} from "ng-zorro-antd/switch";
import {NzDatePickerComponent} from "ng-zorro-antd/date-picker";
import {NzInputNumberModule} from "ng-zorro-antd/input-number";
import {NzTypographyComponent} from "ng-zorro-antd/typography";

@Component({
  selector: 'app-agent-staff',
  standalone: true,
  imports: [
    DatePipe,
    DictionaryPipe,
    FormsModule,
    NgForOf,
    NgIf,
    NzButtonComponent,
    NzCellFixedDirective,
    NzColDirective,
    NzDividerComponent,
    NzDropDownADirective,
    NzDropDownDirective,
    NzDropdownMenuComponent,
    NzFormControlComponent,
    NzFormDirective,
    NzFormItemComponent,
    NzFormLabelComponent,
    NzIconDirective,
    NzInputDirective,
    NzMenuDirective,
    NzMenuItemComponent,
    NzOptionComponent,
    NzRowDirective,
    NzSelectComponent,
    NzTableCellDirective,
    NzTableComponent,
    NzTbodyComponent,
    NzThMeasureDirective,
    NzTheadComponent,
    NzTrDirective,
    ReactiveFormsModule,
    NzTableModule,
    NzModalModule,
    NzFlexDirective,
    NzDescriptionsModule,
    NzUploadComponent,
    NzAvatarModule,
    NzImageModule,
    NzSwitchComponent,
    NzDatePickerComponent,
    NzInputNumberModule,
    NzTypographyComponent
  ],
  templateUrl: './agent-staff.component.html',
  styleUrl: './agent-staff.component.less'
})
export class AgentStaffComponent {
// 表单页数
  tablePageNum = 1;
  // 每页数量
  tablePageSize = 10;
  // 表单数据
  tableData: any = {
    total: 0,
    list: [],
  };
  // 搜索表单
  searchForm: FormGroup;
  // 编辑表单
  editForm: FormGroup;
  editModal = false;
  constructor(private fb: NonNullableFormBuilder,
              private message: NzMessageService,
              private storage: BrowserStorageService,
              private agentStaffService: AgentStaffService,
              private commonService: CommonService,
              private modal: NzModalService) {

    // 初始化搜索框
    this.searchForm = this.fb.group({
      name: [null],
      telephone: [null],
    });

    this.editForm = this.fb.group({
      id: [null],
      name: [null, [Validators.required]],
      telephone: [null, [Validators.required]],
    });
    // 查询数据
    this.queryData();
  }

  /**
   * 获取数据
   */
  queryData() {
    this.searchForm.value.pageNum = this.tablePageNum;
    this.searchForm.value.pageSize = this.tablePageSize;
    this.searchForm.value.time = new Date().getTime();
    this.agentStaffService.getStaffList(this.searchForm.value, (data: any) => {
      if (data['return_code'] == '000000') {
        this.tableData = data['return_data'];
      }
    });
  }

  /**
   * 搜索表单提交
   */
  searchFormSubmit(): void {
    this.tablePageNum = 1;
    this.queryData();
  }

  /**
   * 搜索表单重置
   */
  searchFormReset(): void {
    this.searchForm.reset();
  }

  /**
   * 打开编辑模态框
   */
  showEditModal(data: any) {
    if (data != null) {
      this.editForm.patchValue(data);
    }
    this.editModal = true;
  }

  /**
   * 提交数据
   */
  submitData() {
    if (this.editForm.valid) {
      if (this.editForm.controls['id'].value == null) {
        this.agentStaffService.addStaff(this.editForm.value, (data: any) => {
          if (data['return_code'] == '000000') {
            this.message.create('success', '操作成功');
            // 刷新数据
            this.queryData();
            // 关闭弹窗
            this.closeEditModal();
            // 表单重置
            this.editForm.reset();
          } else {
            this.message.create('error', data['return_msg']);
          }
        });
      } else {
        this.agentStaffService.updateStaff(this.editForm.value, (data: any) => {
          if (data['return_code'] == '000000') {
            this.message.create('success', '操作成功');
            // 刷新数据
            this.queryData();
            // 关闭弹窗
            this.closeEditModal();
            // 表单重置
            this.editForm.reset();
          } else {
            this.message.create('error', data['return_msg']);
          }
        });
      }

    } else {
      Object.values(this.editForm.controls).forEach(control => {
        if (control.invalid) {
          control.markAsDirty();
          control.updateValueAndValidity({ onlySelf: true });
        }
      });
    }
  }

  /**
   * 关闭编辑模态框
   */
  closeEditModal() {
    this.editForm.reset();
    this.editModal = false;
  }

  /**
   * 删除
   */
  delStaff(id: number) {
    this.modal.confirm({
      nzTitle: '提示',
      nzContent: '确定删除账户吗？',
      nzOnOk: () =>
        this.agentStaffService.delStaff({id: id}, (data: any) => {
          if (data['return_code'] == '000000') {
            // 刷新数据
            this.queryData();
            this.message.create('success', '操作成功');
          } else {
            this.message.create('error', data['return_msg']);
          }
        })
    });
  }
}
