import { Component } from '@angular/core';
import {DatePipe, NgForOf, NgIf} from "@angular/common";
import {DictionaryPipe} from "../../../pipes/common/dictionary.pipe";
import {FormGroup, FormsModule, NonNullableFormBuilder, ReactiveFormsModule, Validators} from "@angular/forms";
import {NzButtonComponent} from "ng-zorro-antd/button";
import {
  NzCellFixedDirective,
  NzTableCellDirective,
  NzTableComponent, NzTableModule,
  NzTbodyComponent, NzTheadComponent,
  NzThMeasureDirective, NzTrDirective
} from "ng-zorro-antd/table";
import {NzColDirective, NzRowDirective} from "ng-zorro-antd/grid";
import {NzDatePickerComponent} from "ng-zorro-antd/date-picker";
import {NzFlexDirective} from "ng-zorro-antd/flex";
import {NzFormControlComponent, NzFormDirective, NzFormItemComponent, NzFormLabelComponent} from "ng-zorro-antd/form";
import {NzInputNumberComponent, NzInputNumberModule} from "ng-zorro-antd/input-number";
import {NzModalComponent, NzModalModule, NzModalService} from "ng-zorro-antd/modal";
import {NzOptionComponent, NzSelectComponent} from "ng-zorro-antd/select";
import {NzMessageService} from "ng-zorro-antd/message";
import {BrowserStorageService} from "../../../utils/localStorage.service";
import {OilTaskService} from "../../../services/mer-oil-price/oil-task.service";
import {CommonService} from "../../../services/common/common.service";
import {DATA} from "../../../data/login/localStorage.namespace";
import {NzDividerComponent} from "ng-zorro-antd/divider";
import {NzDropDownADirective, NzDropDownDirective, NzDropdownMenuComponent} from "ng-zorro-antd/dropdown";
import {NzIconDirective} from "ng-zorro-antd/icon";
import {NzInputDirective} from "ng-zorro-antd/input";
import {NzMenuDirective, NzMenuItemComponent} from "ng-zorro-antd/menu";
import {NzDescriptionsModule} from "ng-zorro-antd/descriptions";
import {NzUploadComponent, NzUploadFile} from "ng-zorro-antd/upload";
import {NzAvatarModule} from "ng-zorro-antd/avatar";
import {NzImageModule} from "ng-zorro-antd/image";
import {NzSwitchComponent} from "ng-zorro-antd/switch";
import {environment} from "../../../../environments/environment";
import {CmsService} from "../../../services/cms/cms.service";
import {Observable, Observer} from "rxjs";

@Component({
  selector: 'app-cms-list',
  standalone: true,
  imports: [
    DatePipe,
    DictionaryPipe,
    FormsModule,
    NgForOf,
    NgIf,
    NzButtonComponent,
    NzCellFixedDirective,
    NzColDirective,
    NzDividerComponent,
    NzDropDownADirective,
    NzDropDownDirective,
    NzDropdownMenuComponent,
    NzFormControlComponent,
    NzFormDirective,
    NzFormItemComponent,
    NzFormLabelComponent,
    NzIconDirective,
    NzInputDirective,
    NzMenuDirective,
    NzMenuItemComponent,
    NzOptionComponent,
    NzRowDirective,
    NzSelectComponent,
    NzTableCellDirective,
    NzTableComponent,
    NzTbodyComponent,
    NzThMeasureDirective,
    NzTheadComponent,
    NzTrDirective,
    ReactiveFormsModule,
    NzTableModule,
    NzModalModule,
    NzFlexDirective,
    NzDescriptionsModule,
    NzUploadComponent,
    NzAvatarModule,
    NzImageModule,
    NzSwitchComponent,
    NzDatePickerComponent,
    NzInputNumberModule
  ],
  templateUrl: './cms-list.component.html',
  styleUrl: './cms-list.component.less'
})
export class CmsListComponent {
  BASE_URL = environment.baseUrl;
  IMAGE_URL = environment.imageUrl;
  loading = false;
  logoUrl?: string;
  // 表单页数
  tablePageNum = 1;
  // 每页数量
  tablePageSize = 10;
  // 表单数据
  tableData: any = {
    total: 0,
    list: [],
  };
  accountType = null;
  // 搜索表单
  searchForm: FormGroup;
  // 编辑表单
  editCmsForm: FormGroup;
  editCmsModal = false;
  // 轮播图类型
  cmsTypeArray = new DictionaryPipe().getDictionaryList('CMS_TYPE');
  // 轮播图状态
  cmsStatusArray = new DictionaryPipe().getDictionaryList('CMS_STATUS');
  constructor(private fb: NonNullableFormBuilder,
              private message: NzMessageService,
              private storage: BrowserStorageService,
              private cmsService: CmsService,
              private commonService: CommonService,
              private modal: NzModalService) {
    this.accountType = this.storage.get(DATA)['account']['objectType'];

    // 初始化搜索框
    this.searchForm = this.fb.group({
      type: [null],
      status: [null],
    });

    this.editCmsForm = this.fb.group({
      id: [''],
      type: ['', [Validators.required]],
      imgUrl: ['', [Validators.required]],
      jumpType: [''],
      jumpUrl: [''],
      startTime: [''],
      endTime: [''],
    });
    // 查询数据
    this.queryData();
  }

  /**
   * 获取数据
   */
  queryData() {
    this.searchForm.value.pageNum = this.tablePageNum;
    this.searchForm.value.pageSize = this.tablePageSize;
    this.searchForm.value.time = new Date().getTime();
    this.cmsService.queryList(this.searchForm.value, (data: any) => {
      if (data['return_code'] == '000000') {
        this.tableData = data['return_data'];
      }
    });
  }

  /**
   * 搜索表单提交
   */
  searchFormSubmit(): void {
    this.tablePageNum = 1;
    this.queryData();
  }

  /**
   * 搜索表单重置
   */
  searchFormReset(): void {
    this.searchForm.reset();
  }

  /**
   * 删除
   */
  delCms(id: number) {
    this.modal.confirm({
      nzTitle: '提示',
      nzContent: '确定删除吗？',
      nzOnOk: () =>
        this.cmsService.delete({id: id}, (data: any) => {
          if (data['return_code'] == '000000') {
            // 刷新数据
            this.queryData();
            this.message.create('success', '操作成功');
          } else {
            this.message.create('error', data['return_msg']);
          }
        })
    });
  }

  /**
   * 下线
   */
  offline(id: number) {
    this.modal.confirm({
      nzTitle: '提示',
      nzContent: '确定轮播图下线吗？',
      nzOnOk: () =>
        this.cmsService.offline({id: id}, (data: any) => {
          if (data['return_code'] == '000000') {
            // 刷新数据
            this.queryData();
            this.message.create('success', '操作成功');
          } else {
            this.message.create('error', data['return_msg']);
          }
        })
    });
  }

  /**
   * 上线
   */
  online(data: any) {
    this.modal.confirm({
      nzTitle: '提示',
      nzContent: data.startTime!=null?'已设置自动上线时间，确定需要提前上线吗？':'确定立即上线吗？',
      nzOnOk: () =>
        this.cmsService.online({id: data.id}, (data: any) => {
          if (data['return_code'] == '000000') {
            // 刷新数据
            this.queryData();
            this.message.create('success', '操作成功');
          } else {
            this.message.create('error', data['return_msg']);
          }
        })
    });
  }

  /**
   * 打开编辑模态框
   */
  showEditCmsModal(data: any) {
    if (data != null) {
      this.logoUrl = this.IMAGE_URL + data['imgUrl'];
      data['type'] = ''+data['type'];
      data['jumpType'] = ''+data['jumpType'];
    }
    this.editCmsForm.patchValue(data);
    this.editCmsModal = true;
  }

  /**
   * 提交数据
   */
  submitData() {
    if (this.editCmsForm.valid) {
      if (this.editCmsForm.value.startTime != null && this.editCmsForm.value.startTime != '') {
          console.log(this.editCmsForm.value.startTime);
          let startTime = new Date(this.editCmsForm.value.startTime);
          startTime.setSeconds(0,0);
          console.log(startTime.getTime())
          this.editCmsForm.controls['startTime'].setValue(startTime.getTime());
      }
      if (this.editCmsForm.value.endTime != null && this.editCmsForm.value.endTime != '') {
        let endTime = new Date(this.editCmsForm.value.endTime);
        endTime.setSeconds(0,0);
        this.editCmsForm.controls['endTime'].setValue(endTime.getTime());
      }
      this.cmsService.edit(this.editCmsForm.value, (data: any) => {
        if (data['return_code'] == '000000') {
          this.message.create('success', '操作成功');
          // 刷新数据
          this.queryData();
          // 关闭弹窗
          this.closeEditModal();
          // 表单重置
          this.editCmsForm.reset();
        } else {
          this.message.create('error', data['return_msg']);
        }
      });
    } else {
      Object.values(this.editCmsForm.controls).forEach(control => {
        if (control.invalid) {
          control.markAsDirty();
          control.updateValueAndValidity({ onlySelf: true });
        }
      });
    }
  }

  /**
   * 关闭编辑任务模态框
   */
  closeEditModal() {
    this.editCmsForm.reset();
    this.logoUrl = '';
    this.editCmsModal = false;
  }

  private getBase64(img: File, callback: (img: string) => void): void {
    const reader = new FileReader();
    reader.addEventListener('load', () => callback(reader.result!.toString()));
    reader.readAsDataURL(img);
  }

  handleChange(info: { file: NzUploadFile }): void {
    switch (info.file.status) {
      case 'uploading':
        this.loading = true;
        break;
      case 'done':
        // Get this url from response in real world.
        this.getBase64(info.file!.originFileObj!, (img: string) => {
          this.loading = false;
          this.logoUrl = img;
        });
        // 不是自建站，拼接绝对路径访问链接
        this.editCmsForm.patchValue({ imgUrl: info.file.response['return_data'][0]});
        break;
      case 'error':
        this.message.error('网络错误！');
        this.loading = false;
        break;
    }
  }

  beforeUpload = (file: NzUploadFile, _fileList: NzUploadFile[]) => {
    return new Observable((observer: Observer<boolean>) => {
      const isJpgOrPng = file.type === 'image/jpeg' || file.type === 'image/png';
      if (!isJpgOrPng) {
        this.message.error('只能上传JPG文件!');
        observer.complete();
        return;
      }
      const isLt2M = file.size! / 1024 / 1024 < 2;
      if (!isLt2M) {
        this.message.error('图片必须小于2MB!');
        observer.complete();
        return;
      }
      observer.next(isJpgOrPng && isLt2M);
      observer.complete();
    });
  };
}
