import { Component } from '@angular/core';
import {DatePipe, NgForOf, NgIf} from "@angular/common";
import {FormBuilder, FormGroup, FormsModule, ReactiveFormsModule, Validators} from "@angular/forms";
import {NzButtonComponent} from "ng-zorro-antd/button";
import {
  NzCellFixedDirective,
  NzTableCellDirective,
  NzTableComponent, NzTableModule,
  NzTbodyComponent, NzTheadComponent,
  NzThMeasureDirective, NzTrDirective
} from "ng-zorro-antd/table";
import {NzColDirective, NzRowDirective} from "ng-zorro-antd/grid";
import {NzDescriptionsComponent, NzDescriptionsItemComponent, NzDescriptionsModule} from "ng-zorro-antd/descriptions";
import {NzDividerComponent} from "ng-zorro-antd/divider";
import {NzDropDownADirective, NzDropDownDirective, NzDropdownMenuComponent} from "ng-zorro-antd/dropdown";
import {NzFormControlComponent, NzFormDirective, NzFormItemComponent, NzFormLabelComponent} from "ng-zorro-antd/form";
import {NzIconDirective} from "ng-zorro-antd/icon";
import {NzMenuDirective, NzMenuItemComponent} from "ng-zorro-antd/menu";
import {NzModalComponent, NzModalModule, NzModalService} from "ng-zorro-antd/modal";
import {NzOptionComponent, NzSelectComponent} from "ng-zorro-antd/select";
import {NzStatisticComponent, NzStatisticModule} from "ng-zorro-antd/statistic";
import {NzWaveDirective} from "ng-zorro-antd/core/wave";
import {NzMessageService} from "ng-zorro-antd/message";
import {MerClassGroupService} from "../../../services/merchant/mer-class-group.service";
import {MerClassGroupTaskService} from "../../../services/merchant/mer-class-group-task.service";
import {DATA} from "../../../data/login/localStorage.namespace";
import {BrowserStorageService} from "../../../utils/localStorage.service";
import {MerClassGroupTaskStatusPipe} from "../../../pipes/mer-class-group-task/mer-class-group-task-status.pipe";
import {DictionaryPipe} from "../../../pipes/common/dictionary.pipe";
import {NzInputDirective} from "ng-zorro-antd/input";
import {NzFlexDirective} from "ng-zorro-antd/flex";
import {NzUploadComponent} from "ng-zorro-antd/upload";
import {NzAvatarModule} from "ng-zorro-antd/avatar";
import {NzImageModule} from "ng-zorro-antd/image";
import {NzSwitchComponent} from "ng-zorro-antd/switch";
import {NzDatePickerComponent, NzRangePickerComponent} from "ng-zorro-antd/date-picker";
import {NzRadioButtonDirective, NzRadioComponent, NzRadioGroupComponent} from "ng-zorro-antd/radio";
import {NzToolTipModule} from "ng-zorro-antd/tooltip";
import {NzTabsModule} from "ng-zorro-antd/tabs";
import {NzTagModule} from "ng-zorro-antd/tag";
import {NzCardModule} from "ng-zorro-antd/card";
import {NzInputNumberModule} from "ng-zorro-antd/input-number";
import {NzQRCodeModule} from "ng-zorro-antd/qr-code";
import {RouterLink} from "@angular/router";

@Component({
  selector: 'app-mer-class-group-task',
  standalone: true,
  imports: [
    DatePipe,
    DictionaryPipe,
    FormsModule,
    NgForOf,
    NgIf,
    NzButtonComponent,
    NzCellFixedDirective,
    NzColDirective,
    NzDividerComponent,
    NzDropDownADirective,
    NzDropDownDirective,
    NzDropdownMenuComponent,
    NzFormControlComponent,
    NzFormDirective,
    NzFormItemComponent,
    NzFormLabelComponent,
    NzIconDirective,
    NzInputDirective,
    NzMenuDirective,
    NzMenuItemComponent,
    NzOptionComponent,
    NzRowDirective,
    NzSelectComponent,
    NzTableCellDirective,
    NzTableComponent,
    NzTbodyComponent,
    NzThMeasureDirective,
    NzTheadComponent,
    NzTrDirective,
    ReactiveFormsModule,
    NzTableModule,
    NzModalModule,
    NzFlexDirective,
    NzDescriptionsModule,
    NzUploadComponent,
    NzAvatarModule,
    NzImageModule,
    NzSwitchComponent,
    NzDatePickerComponent,
    NzRadioButtonDirective,
    NzRadioComponent,
    NzRadioGroupComponent,
    NzRangePickerComponent,
    NzToolTipModule,
    NzTabsModule,
    NzTagModule,
    NzCardModule,
    NzInputNumberModule,
    NzQRCodeModule,
    RouterLink,
    NzStatisticModule,
    MerClassGroupTaskStatusPipe
  ],
  templateUrl: './mer-class-group-task.component.html',
  styleUrl: './mer-class-group-task.component.less'
})
export class MerClassGroupTaskComponent {
  userInfoObject: any;

  dataObject: any = {};
  tableLoading = true;
  searchForm: FormGroup;
  pageNum: number = 1;
  whereObject: any = {};

  classGroupArray: any = [];

  startClassGroupModal = false;
  startClassGroupModalForm: FormGroup;

  swapClassGroupModal = false;
  swapClassGroupModalForm: FormGroup;

  currentClassGroupCountData: any = {
    classNum: '无',
    refuelPrice: '0',
    refuelNum: '0',
    refuelLiters: '0',
    refundPrice: '0',
    refundNum: '0',
    status: null,
  };

  classGroupCountDataModal = false;
  classGroupCountData: any = {};

  printModal = false;
  printData = {};
  printTaskId: number = 0;

  constructor(private modal: NzModalService,
              private storage: BrowserStorageService,
              private message: NzMessageService,
              private gasClassGroupService: MerClassGroupService,
              private gasClassGroupTaskService: MerClassGroupTaskService,
              private form: FormBuilder) {
    this.userInfoObject = this.storage.get(DATA);

    this.searchForm = this.form.group({
      name: [null],
      principalName: [null],
      principalPhone: [null],
    });

    this.startClassGroupModalForm = this.form.group({
      gasId: [null],
      gasClassGroupId: [null, [Validators.required]],
    });

    this.swapClassGroupModalForm = this.form.group({
      gasId: [null],
      gasClassGroupId: [null, [Validators.required]],
    });

    this.gasClassGroupService.getClassGroupList({pageNum: 1, pageSize: 9999}, (data: any) => {
      if (data['return_code'] === '000000') {
        this.classGroupArray = data['return_data']['list'];
      }
    });
    this.getCurrentClassGroupCountData();
    this.requestData(1);

  }
  /**
   * 请求数据
   */
  requestData(pageNum: number) {
    if (pageNum != null) {
      this.tableLoading = true;
      this.whereObject['pageNum'] = pageNum;
      this.whereObject['pageSize'] = 10;
      this.whereObject['time'] = new Date().getTime();
      this.gasClassGroupTaskService.getClassGroupTaskList(this.whereObject, (data: any) => {
        if (data['return_code'] === '000000') {
          this.dataObject = data['return_data'];
        } else {
          this.modal.error(data['return_msg']);
        }
        this.tableLoading = false;
      });
    }
  }

  /**
   * 搜索
   * @param whereObject 条件
   */
  search(whereObject: object) {
    this.whereObject = whereObject;
    this.requestData(1);
  }

  /**
   * 重置
   */
  resetForm(): void {
    this.searchForm.reset();
  }

  /**
   * 查询当前班组数据
   */
  getCurrentClassGroupCountData() {
    this.gasClassGroupTaskService.getCurrentClassGroupTask(this.userInfoObject['account']['objectId'], (data: any) => {
      if (data['return_code'] === '000000') {
        this.currentClassGroupCountData = data['return_data'];
      } else {
        this.modal.warning({
          nzTitle: '提示',
          nzContent: data['return_msg'],
        });
      }
    });

    this.requestData(this.whereObject['pageNum']);
  }

  /**
   * 打开 开始班组模态框
   */
  showStartClassGroupModal() {
    this.startClassGroupModal = true;
  }

  /**
   *
   * 关闭 开始班组模态框
   */
  closeStartClassGroupModal() {
    this.startClassGroupModalForm.reset();
    this.startClassGroupModal = false;
  }

  /**
   * 提交 开始班组数据
   */
  submitStartClassGroup(){
    for (const i in this.startClassGroupModalForm.controls) {
      this.startClassGroupModalForm.controls[i].markAsDirty();
      this.startClassGroupModalForm.controls[i].updateValueAndValidity();
    }
    if (this.startClassGroupModalForm.status == null || this.startClassGroupModalForm.status !== 'VALID') {
      this.modal.warning({
        nzTitle: '提示',
        nzContent: '请填写所有必填项',
      });
      return;
    }
    this.startClassGroupModalForm.value.gasId = this.userInfoObject['account']['objectId'];

    // 提交数据
    this.gasClassGroupTaskService.startGroupTask(this.startClassGroupModalForm.value, (data:any) => {
      if (data['return_code'] === '000000') {
        this.modal.success({
          nzTitle: '提示',
          nzContent: '操作成功',
        });
        this.getCurrentClassGroupCountData();
        this.requestData(this.whereObject['pageNum']);
        this.closeStartClassGroupModal();
      } else {
        this.modal.warning({
          nzTitle: '提示',
          nzContent: data['return_msg'],
        });
      }
    });
  }


  /**
   * 打开 交换班组模态框
   */
  showSwapClassGroupModal() {
    this.swapClassGroupModal = true;
  }

  /**
   * 关闭 交换班组模态框
   */
  closeSwapClassGroupModal() {
    this.swapClassGroupModalForm.reset();
    this.swapClassGroupModal = false;
  }

  /**
   * 提交 交换班组提醒框
   */
  submitSwapClassGroupConfirm() {
    this.modal.confirm({
      nzTitle: '警告',
      nzContent: '确定交换班次吗？',
      nzOkText: '是',
      nzCancelText: '否',
      nzOnOk: () => this.submitSwapClassGroup()
    });
  }

  /**
   * 提交 交换班组数据
   */
  submitSwapClassGroup() {
    for (const i in this.swapClassGroupModalForm.controls) {
      this.swapClassGroupModalForm.controls[i].markAsDirty();
      this.swapClassGroupModalForm.controls[i].updateValueAndValidity();
    }
    if (this.swapClassGroupModalForm.status == null || this.swapClassGroupModalForm.status !== 'VALID') {
      this.modal.warning({
        nzTitle: '提示',
        nzContent: '请填写所有必填项',
      });
      return;
    }
    this.swapClassGroupModalForm.value.gasId = this.userInfoObject['account']['objectId'];

    // 提交数据
    this.gasClassGroupTaskService.swapGroupTask(this.swapClassGroupModalForm.value, (data:any) => {
      if (data['return_code'] === '000000') {
        this.modal.success({
          nzTitle: '提示',
          nzContent: '操作成功',
        });
        this.getCurrentClassGroupCountData();
        this.requestData(this.whereObject['pageNum']);
        this.closeSwapClassGroupModal();
      } else {
        this.modal.warning({
          nzTitle: '提示',
          nzContent: data['return_msg'],
        });
      }
    });
  }


  /**
   * 弹出结束对话框
   */
  showEndClassGroupConfirm(): void {
    this.modal.confirm({
      nzTitle: '警告',
      nzContent: '确定结束本次班次吗？',
      nzOkText: '是',
      nzCancelText: '否',
      nzOnOk: () => this.endClassGroupData()
    });
  }

  /**
   * 提交结束班次数据
   *
   */
  endClassGroupData() {
    this.gasClassGroupTaskService.endGroupTask( { gasId: this.userInfoObject['account']['objectId'], }, (data:any) => {
      if (data['return_code'] === '000000') {
        this.requestData(this.whereObject['pageNum']);
        this.getCurrentClassGroupCountData();
      } else {
        this.modal.error({
          nzTitle: '提示',
          nzContent: data['return_msg']
        });
      }
    });
  }

  /**
   * 展示班次数据统计
   */
  showClassGroupTaskDataModal(data: any) {
    this.classGroupCountData = JSON.parse(data['dataCount']);
    this.printTaskId = data['id'];
    this.classGroupCountDataModal = true;
  }

  /**
   * 关闭班次数据统计
   */
  closeClassGroupTaskDataModal() {
    this.classGroupCountDataModal = false;
  }

  /**
   * 展示打印模态框
   * @param data
   */
  showPrintModal(data: object) {
    this.printData = data;
    this.printModal = true;
  }

  /**
   * 云打印
   */
  cloudPrint() {
    this.gasClassGroupTaskService.print(this.printTaskId, (data: any) => {
      if (data['return_code'] === '000000') {
        this.modal.success({
          nzTitle: '提示',
          nzContent: '操作成功',
        });
        this.printModal = false;
      }
    });
  }
}
