import {Component, ElementRef, ViewChild} from '@angular/core';
import {DatePipe, NgForOf, NgIf} from "@angular/common";
import {DictionaryPipe} from "../../../pipes/common/dictionary.pipe";
import {FormGroup, FormsModule, NonNullableFormBuilder, ReactiveFormsModule, Validators} from "@angular/forms";
import {NzButtonComponent} from "ng-zorro-antd/button";
import {
  NzCellFixedDirective,
  NzTableCellDirective,
  NzTableComponent, NzTableModule,
  NzTbodyComponent, NzTheadComponent,
  NzThMeasureDirective, NzTrDirective
} from "ng-zorro-antd/table";
import {NzColDirective, NzRowDirective} from "ng-zorro-antd/grid";
import {NzDividerComponent} from "ng-zorro-antd/divider";
import {NzDropDownADirective, NzDropDownDirective, NzDropdownMenuComponent} from "ng-zorro-antd/dropdown";
import {NzFormControlComponent, NzFormDirective, NzFormItemComponent, NzFormLabelComponent} from "ng-zorro-antd/form";
import {NzIconDirective} from "ng-zorro-antd/icon";
import {NzInputDirective} from "ng-zorro-antd/input";
import {NzMenuDirective, NzMenuItemComponent} from "ng-zorro-antd/menu";
import {NzOptionComponent, NzSelectComponent} from "ng-zorro-antd/select";
import {NzMessageService} from "ng-zorro-antd/message";
import {NzModalModule, NzModalService} from "ng-zorro-antd/modal";
import {NzFlexDirective} from "ng-zorro-antd/flex";
import {NzDescriptionsModule} from "ng-zorro-antd/descriptions";
import {NzUploadComponent, NzUploadFile} from "ng-zorro-antd/upload";
import {environment} from "../../../../environments/environment";
import {Observable, Observer} from "rxjs";
import {NzAvatarModule} from "ng-zorro-antd/avatar";
import {MerService} from "../../../services/merchant/mer.service";
import {RoleService} from "../../../services/role/role.service";
import {NzImageModule} from "ng-zorro-antd/image";
import {NzSwitchComponent} from "ng-zorro-antd/switch";
import {NzDatePickerComponent, NzRangePickerComponent} from "ng-zorro-antd/date-picker";
import {NzRadioButtonDirective, NzRadioComponent, NzRadioGroupComponent} from "ng-zorro-antd/radio";
import {CommonService} from "../../../services/common/common.service";
import { NzToolTipModule } from 'ng-zorro-antd/tooltip';
import {NzTabsModule} from "ng-zorro-antd/tabs";
import {NzTagModule} from "ng-zorro-antd/tag";
import {NzQRCodeModule} from "ng-zorro-antd/qr-code";
import {NzCardModule} from "ng-zorro-antd/card";
import {NzInputNumberModule} from "ng-zorro-antd/input-number";
import {RouterLink} from "@angular/router";
@Component({
  selector: 'app-mer-list',
  standalone: true,
  imports: [
    DatePipe,
    DictionaryPipe,
    FormsModule,
    NgForOf,
    NgIf,
    NzButtonComponent,
    NzCellFixedDirective,
    NzColDirective,
    NzDividerComponent,
    NzDropDownADirective,
    NzDropDownDirective,
    NzDropdownMenuComponent,
    NzFormControlComponent,
    NzFormDirective,
    NzFormItemComponent,
    NzFormLabelComponent,
    NzIconDirective,
    NzInputDirective,
    NzMenuDirective,
    NzMenuItemComponent,
    NzOptionComponent,
    NzRowDirective,
    NzSelectComponent,
    NzTableCellDirective,
    NzTableComponent,
    NzTbodyComponent,
    NzThMeasureDirective,
    NzTheadComponent,
    NzTrDirective,
    ReactiveFormsModule,
    NzTableModule,
    NzModalModule,
    NzFlexDirective,
    NzDescriptionsModule,
    NzUploadComponent,
    NzAvatarModule,
    NzImageModule,
    NzSwitchComponent,
    NzDatePickerComponent,
    NzRadioButtonDirective,
    NzRadioComponent,
    NzRadioGroupComponent,
    NzRangePickerComponent,
    NzToolTipModule,
    NzTabsModule,
    NzTagModule,
    NzCardModule,
    NzInputNumberModule,
    NzQRCodeModule,
    RouterLink
  ],
  templateUrl: './mer-list.component.html',
  styleUrl: './mer-list.component.less'
})
export class MerListComponent {
  IMAGE_URL = environment.imageUrl;
  // 表单页数
  tablePageNum = 1;
  // 每页数量
  tablePageSize = 10;
  // 表单数据
  tableData: any = {
    total: 0,
    list: [],
  };
  // 搜索表单
  searchForm: FormGroup;
  // 更多搜索条件
  isCollapse = false;
  // 油站状态
  merchantStatusArray = new DictionaryPipe().getDictionaryList('MERCHANT_STATUS');
  // 油站来源
  merSourceTypeArray = new DictionaryPipe().getDictionaryList('MER_SOURCE_TYPE');
  // 地区数据
  regionData: any = []

  merDetailVisible = false;
  merDetailObject: any = {
    merchant: {},
    oils: [],
  };

  merQrCodeVisible = false;
  merQrCodeData: any = [];

  // 支付配置表单
  payConfigForm: FormGroup;
  payConfigModal = false;

  ledgerDataForm: FormGroup;
  ledgerDataModal = false;

  constructor(private fb: NonNullableFormBuilder,
              private merService: MerService,
              private roleService: RoleService,
              private message: NzMessageService,
              private commonService: CommonService,
              private modal: NzModalService) {
    // 初始化搜索框
    this.searchForm = this.fb.group({
      sourceType: [''],
      provinceCode: [''],
      merNo: [''],
      merName: [''],
      status: [''],
    });

    // 初始化表单
    this.payConfigForm = this.fb.group({
      merNo: ['', [Validators.required]],
      channelMerNo: ['', [Validators.required]],
      channelMerKey: ['', [Validators.required]],
      ledgerAccountFlag: [0, [Validators.required]],
      ledgerAccountData: [[]],
    });

    this.ledgerDataForm = this.fb.group({
      index: ['', [Validators.required]],
      receiverMerNo: ['', [Validators.required]],
      receiverMerName: ['', [Validators.required]],
      receiverRatio: [0, [Validators.required]],
    });

    // 获取地区
    this.commonService.getRegion("", (data: any) => {
      this.regionData = data['return_data'];
    });

    this.queryData();
  }

  /**
   * 获取数据
   */
  queryData() {
    this.searchForm.value.pageNum = this.tablePageNum;
    this.searchForm.value.pageSize = this.tablePageSize;
    this.searchForm.value.time = new Date().getTime();
    this.merService.queryMerList(this.searchForm.value, (data: any) => {
      if (data['return_code'] == '000000') {
        this.tableData = data['return_data'];
      }
    });
  }

  /**
   * 搜索表单提交
   */
  searchFormSubmit(): void {
    this.tablePageNum = 1;
    this.queryData();
  }

  /**
   * 搜索表单重置
   */
  searchFormReset(): void {
    this.searchForm.reset();
  }

  /**
   * 展示商户详情
   * @param merNo
   */
  showMerDetail(merNo: string) {
    this.merService.queryMer(merNo, (data: any) => {
      if (data['return_code'] == '000000') {
        this.merDetailObject = data['return_data'];

        for (let item of this.merDetailObject.oils) {
           item['gunNoListStr'] = (item['gunNoList'].map((item: any) => item['gunNo']).join('号枪，'));
        }
      } else {
        this.message.error(data['return_msg']);
      }
    });
    this.merDetailVisible = true;
  }

  /**
   * 关闭商户详情
   */
  closeMerDetail() {
    this.merDetailObject = {
      merchant: {},
      oils: [],
    };
    this.merDetailVisible = false;
  }

  /**
   * 展示商户二维码
   * @param merNo
   */
  showMerQrCode(merNo: string) {
    this.merService.queryQrCodeList(merNo, (data: any) => {
      if (data['return_code'] == '000000') {
        this.merQrCodeData = data['return_data'];

      } else {
        this.message.error(data['return_msg']);
      }
    });
    this.merQrCodeVisible = true;
  }

  /**
   * 关闭商户二维码展示
   */
  closeMerQrCode() {
    this.merQrCodeVisible = false;
  }

  /**
   * 列是否表展示
   */
  listShowChange(merNo: string) {
    this.merService.listShow({merNo: merNo}, (data: any) => {
      if (data['return_code'] == '000000') {
        this.message.success("操作成功");
      } else {
        this.message.error(data['return_msg']);
      }
    });
  }

  /**
   * 打开密码重置确认框
   */
  showResetPwd(merNo: string) {
    this.modal.confirm({
      nzTitle: '提示',
      nzContent: '确定重置油站账户登录密码吗？',
      nzOnOk: () =>
        this.merService.resetPwd({merNo: merNo}, (data: any) => {
          if (data['return_code'] == '000000') {
            // 刷新数据
            this.queryData();
            this.modal.success({
              nzTitle: '提示',
              nzContent: '密码重置成功，新密码：123654'
            });
          } else {
            this.message.create('error', data['return_msg']);
          }
        })
    });
  }

  /**
   * 打开禁用确认框
   */
  showDisable(merNo: string) {
    this.modal.confirm({
      nzTitle: '提示',
      nzContent: '确定禁用油站吗？禁用后无法交易',
      nzOnOk: () =>
        this.merService.disableMer({merNo: merNo}, (data: any) => {
          if (data['return_code'] == '000000') {
            // 刷新数据
            this.queryData();
            this.modal.success({
              nzTitle: '提示',
              nzContent: '操作成功'
            });
          } else {
            this.message.create('error', data['return_msg']);
          }
        })
    });
  }

  /**
   * 打开启用确认框
   */
  showEnable(merNo: string) {
    this.modal.confirm({
      nzTitle: '提示',
      nzContent: '确定启用油站吗？',
      nzOnOk: () =>
        this.merService.restoreMer({merNo: merNo}, (data: any) => {
          if (data['return_code'] == '000000') {
            // 刷新数据
            this.queryData();
            this.modal.success({
              nzTitle: '提示',
              nzContent: '操作成功'
            });
          } else {
            this.message.create('error', data['return_msg']);
          }
        })
    });
  }

  /**
   * 下载二维码
   * @param type
   */
  @ViewChild('download', { static: false }) download!: ElementRef;
  downloadMerQrCode(type: number) {
    const canvas = document.getElementById('download'+(type==1?'H5':'Wx'))?.querySelector<HTMLCanvasElement>('canvas');
    if (canvas) {
      this.download.nativeElement.href = canvas.toDataURL('image/png');
      this.download.nativeElement.download = new Date().getTime();
      const event = new MouseEvent('click');
      this.download.nativeElement.dispatchEvent(event);
    }
  }

  /**
   * 打开支付配置模态框
   * @param merNo
   */
  showPayConfigModal(merNo: string) {
    this.merService.queryConfig(merNo, (data : any) => {
       let returnData = data['return_data'];
       if (returnData == null) {
         returnData = {
           merNo: merNo
         };
         returnData['ledgerAccountFlag'] = false;
       } else {
         returnData['ledgerAccountFlag'] = returnData['ledgerAccountFlag']?true:false;
       }
       if (returnData['ledgerAccountFlag'] == true) {
         returnData['ledgerAccountData'] = JSON.parse(returnData['ledgerAccountData']);
       }
       this.payConfigForm.patchValue(returnData);
    });
    this.payConfigModal = true;
  }

  /**
   * 提交收款配置
   */
  submitPayConfig() {
    if (this.payConfigForm.valid) {
        let param = this.payConfigForm.value;
        param['ledgerAccountData'] = JSON.stringify(param['ledgerAccountData']);
        this.merService.editPayConfig(param, (data: any) => {
          if (data['return_code'] == '000000') {
            this.message.create('success', '操作成功');
            // 关闭弹窗
            this.closePayConfigModal();
          } else {
            this.message.create('error', data['return_msg']);
          }
        });
    } else {
      Object.values(this.payConfigForm.controls).forEach(control => {
        if (control.invalid) {
          control.markAsDirty();
          control.updateValueAndValidity({ onlySelf: true });
        }
      });
    }
  }

  /**
   * 关闭支付配置模态框
   */
  closePayConfigModal() {
    this.payConfigForm.reset();
    this.payConfigModal = false;
  }

  /**
   * 打开分账接收方
   * @param arrayIndex
   * @param data
   */
  showLedgerData(arrayIndex: number, data: any) {
     if (arrayIndex == -1) {
       data = {};
     }
     data.index = arrayIndex;
     this.ledgerDataForm.reset(data);
     this.ledgerDataModal = true;
  }

  /**
   * 删除分账接收方数据
   * @param arrayIndex
   */
  delLedgerData(arrayIndex: number) {
    let ledgerAccountArr = [...this.payConfigForm.controls['ledgerAccountData'].value];
    ledgerAccountArr.splice(arrayIndex,1);
    // 数据重新赋值
    this.payConfigForm.controls['ledgerAccountData'].setValue(ledgerAccountArr);
  }

  /**
   * 提交分账接收方 增加、修改
    */
  submitLedgerData() {
    if (this.ledgerDataForm.valid) {
      let ledgerAccountArr = [...this.payConfigForm.controls['ledgerAccountData'].value];
      if (this.ledgerDataForm.controls['index'].value == -1) {
        // 增加数据
        this.ledgerDataForm.controls['index'].setValue(ledgerAccountArr.length + 1);
        ledgerAccountArr.push(this.ledgerDataForm.value);
      } else {
        // 更新数据
        ledgerAccountArr[this.ledgerDataForm.controls['index'].value] = this.ledgerDataForm.value;
      }
      // 数据重新赋值
      this.payConfigForm.controls['ledgerAccountData'].setValue(ledgerAccountArr);
      // 关闭弹窗
      this.closeLedgerData();
    } else {
      Object.values(this.ledgerDataForm.controls).forEach(control => {
        if (control.invalid) {
          control.markAsDirty();
          control.updateValueAndValidity({ onlySelf: true });
        }
      });
    }
  }

  /**
   * 关闭分账接收方弹窗
   */
  closeLedgerData() {
    this.ledgerDataForm.reset();
    this.ledgerDataModal = false;
  }
}
