import {Component, Input, OnInit} from '@angular/core';
import {DatePipe, NgForOf, NgIf} from "@angular/common";
import {NzButtonComponent} from "ng-zorro-antd/button";
import {NzColDirective, NzRowDirective} from "ng-zorro-antd/grid";
import {NzDatePickerComponent, NzDatePickerModule, NzRangePickerComponent} from "ng-zorro-antd/date-picker";
import {NzFormControlComponent, NzFormDirective, NzFormItemComponent, NzFormLabelComponent} from "ng-zorro-antd/form";
import {NzOptionComponent, NzSelectComponent} from "ng-zorro-antd/select";
import {NzRadioButtonDirective, NzRadioComponent, NzRadioGroupComponent, NzRadioModule} from "ng-zorro-antd/radio";
import {NzStatisticComponent, NzStatisticModule} from "ng-zorro-antd/statistic";
import {
  NzCellFixedDirective,
  NzTableCellDirective,
  NzTableComponent, NzTableModule,
  NzTbodyComponent,
  NzTheadComponent,
  NzThMeasureDirective, NzTrDirective
} from "ng-zorro-antd/table";
import {FormGroup, FormsModule, NonNullableFormBuilder, ReactiveFormsModule} from "@angular/forms";
import {DateSelectType, DateUtils} from "../../../utils/dateUtils.service";
import {NzMessageService} from "ng-zorro-antd/message";
import {BrowserStorageService} from "../../../utils/localStorage.service";
import {SpreadUserService} from "../../../services/spread/spread-user.service";
import {CommonService} from "../../../services/common/common.service";
import {NzModalModule, NzModalService} from "ng-zorro-antd/modal";
import {DictionaryPipe} from "../../../pipes/common/dictionary.pipe";
import {NzDividerComponent} from "ng-zorro-antd/divider";
import {NzDropDownADirective, NzDropDownDirective, NzDropdownMenuComponent} from "ng-zorro-antd/dropdown";
import {NzIconDirective} from "ng-zorro-antd/icon";
import {NzInputDirective} from "ng-zorro-antd/input";
import {NzMenuDirective, NzMenuItemComponent} from "ng-zorro-antd/menu";
import {NzFlexDirective} from "ng-zorro-antd/flex";
import {NzDescriptionsModule} from "ng-zorro-antd/descriptions";
import {NzUploadComponent} from "ng-zorro-antd/upload";
import {NzAvatarModule} from "ng-zorro-antd/avatar";
import {NzImageModule} from "ng-zorro-antd/image";
import {NzSwitchComponent} from "ng-zorro-antd/switch";
import {NzInputNumberModule} from "ng-zorro-antd/input-number";
import {WeekPipe} from "../../../pipes/common/week.pipe";

@Component({
  selector: 'app-spread-commission',
  standalone: true,
  imports: [
    DatePipe,
    DictionaryPipe,
    FormsModule,
    NgForOf,
    NgIf,
    NzButtonComponent,
    NzCellFixedDirective,
    NzColDirective,
    NzDividerComponent,
    NzDropDownADirective,
    NzDropDownDirective,
    NzDropdownMenuComponent,
    NzFormControlComponent,
    NzFormDirective,
    NzFormItemComponent,
    NzFormLabelComponent,
    NzIconDirective,
    NzInputDirective,
    NzMenuDirective,
    NzMenuItemComponent,
    NzOptionComponent,
    NzRowDirective,
    NzSelectComponent,
    NzTableCellDirective,
    NzTableComponent,
    NzTbodyComponent,
    NzThMeasureDirective,
    NzTheadComponent,
    NzTrDirective,
    ReactiveFormsModule,
    NzTableModule,
    NzModalModule,
    NzFlexDirective,
    NzDescriptionsModule,
    NzUploadComponent,
    NzAvatarModule,
    NzImageModule,
    NzSwitchComponent,
    NzDatePickerComponent,
    NzInputNumberModule,
    WeekPipe,
    NzStatisticModule,
    NzRadioModule,
    NzDatePickerModule
  ],
  templateUrl: './spread-commission.component.html',
  styleUrl: './spread-commission.component.less'
})
export class SpreadCommissionComponent implements OnInit {
  @Input() userId: any;
  // 表单页数
  tablePageNum = 1;
  // 每页数量
  tablePageSize = 10;
  // 表单数据
  tableData: any = [];
  // 搜索表单
  searchForm: FormGroup;
  // 时间快速选择项
  dateTypeSelect = DateSelectType;
  countData = 0;
  constructor(private fb: NonNullableFormBuilder,
              private message: NzMessageService,
              private storage: BrowserStorageService,
              private spreadUserService: SpreadUserService,
              private commonService: CommonService,
              private modal: NzModalService) {
    // 初始化搜索框
    this.searchForm = this.fb.group({
      userId: [null],
      orderStatus: ['2'],
      payTimeSelect: ['1'],
      payTimeArray: [[]],
      payTimeS: [null],
      payTimeE: [null],
    });
    // 初始化创建时间
    this.payTimeInit();

  }

  ngOnInit(): void {
    // 查询佣金统计
    this.countAccount();
    // 查询数据
    this.queryData();
  }

  /**
   * 创建时间初始化
   */
  payTimeInit() {
    let createTimeSelect = this.searchForm.controls['payTimeSelect'].value;
    if (createTimeSelect != null) {
      let timeObj = DateUtils.getDate(new Date(), Number(createTimeSelect));
      this.searchForm.controls['payTimeArray'].setValue([timeObj.timeS, timeObj.timeE]);
    }
  }

  /**
   * 查询佣金统计
   */
  countAccount() {
    if (this.searchForm.controls['payTimeArray'].value != null
      && this.searchForm.controls['payTimeArray'].value.length > 0) {
      this.searchForm.controls['payTimeS'].setValue(new Date(this.searchForm.controls['payTimeArray'].value[0]).getTime());
      this.searchForm.controls['payTimeE'].setValue(new Date(this.searchForm.controls['payTimeArray'].value[1]).getTime());
    } else {
      this.searchForm.controls['payTimeS'].setValue(null);
      this.searchForm.controls['payTimeE'].setValue(null);
    }
    this.searchForm.value.userId = this.userId;
    // 佣金情况
    this.spreadUserService.countAccount(this.searchForm.value,(data: any) => {
      if (data['return_code'] == '000000'){
        this.countData = data['return_data'];
      }
    })
  }
  /**
   * 获取数据
   */
  queryData() {
    if (this.searchForm.controls['payTimeArray'].value != null
      && this.searchForm.controls['payTimeArray'].value.length > 0) {
      this.searchForm.controls['payTimeS'].setValue(new Date(this.searchForm.controls['payTimeArray'].value[0]).getTime());
      this.searchForm.controls['payTimeE'].setValue(new Date(this.searchForm.controls['payTimeArray'].value[1]).getTime());
    } else {
      this.searchForm.controls['payTimeS'].setValue(null);
      this.searchForm.controls['payTimeE'].setValue(null);
    }
    this.searchForm.value.userId = this.userId;
    this.searchForm.value.pageNum = this.tablePageNum;
    this.searchForm.value.pageSize = this.tablePageSize;
    this.searchForm.value.time = new Date().getTime();
    this.spreadUserService.queryOilOrderSpread(this.searchForm.value, (data: any) => {
      if (data['return_code'] == '000000') {
        this.tableData = data['return_data'];
      }
    });
  }

  /**
   * 搜索表单提交
   */
  searchFormSubmit(): void {
    this.queryData();
    this.countAccount();
  }

  /**
   * 搜索表单重置
   */
  searchFormReset(): void {
    this.searchForm.reset();
  }
}
