import { Injectable } from '@angular/core';
import {HttpClient} from '@angular/common/http';
import {environment} from "../../../environments/environment";
import {ObjectData} from "../../utils/objectData.service";

@Injectable({
  providedIn: 'root'
})
export class MerClassGroupService {

  constructor(
      private http: HttpClient
  ) { }

  /**
   * 编辑班组
   *
   * @param  param   参数对象
   * @param  callBack   回调
   */
  public editClassGroup(param: object, callBack: any) {
    this.http.post(environment.baseUrl + 'gasClassGroup/editClassGroup', param).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 删除班组
   *
   * @param  param   参数对象
   * @param  callBack   回调
   */
  public delClassGroup(groupId: number, callBack: any) {
    this.http.post(environment.baseUrl + 'gasClassGroup/delClassGroup', { id: groupId}).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 根据id查询详情
   *
   * @param  groupId   班组id
   * @param  callBack   回调
   */
  public getClassGroupById(groupId: number, callBack: any) {
    this.http.get(environment.baseUrl + 'gasClassGroup/getClassGroupById?groupId=' + groupId).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 查询班组列表
   *
   * @param  param   参数对象
   * @param  callBack   回调
   */
  public getClassGroupList(param: Object, callBack: any) {
    this.http.get(environment.baseUrl + 'gasClassGroup/getClassGroupList?'+ObjectData.objectByString(param)).subscribe(data => {
      callBack(data);
    });
  }
}
