import { Injectable } from '@angular/core';
import {HttpClient} from "@angular/common/http";
import {environment} from "../../../environments/environment";
import {ObjectData} from "../../utils/objectData.service";

@Injectable({
  providedIn: 'root'
})
export class MerService {

  constructor(private http: HttpClient) { }

  /**
   * 编辑商户
   * @param params
   * @param callBack
   */
  public editMerchant(params: any, callBack:any) {
    params.time = new Date().getTime();
    this.http.post(environment.baseUrl + 'merchant/editMerchant', params).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 列表展示
   * @param params
   * @param callBack
   */
  public listShow(params: any, callBack:any) {
    params.time = new Date().getTime();
    this.http.post(environment.baseUrl + 'merchant/listShow', params).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 密码重置
   * @param params
   * @param callBack
   */
  public resetPwd(params: any, callBack:any) {
    params.time = new Date().getTime();
    this.http.post(environment.baseUrl + 'merchant/resetMerPwd', params).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 启用油站
   * @param params
   * @param callBack
   */
  public restoreMer(params: any, callBack:any) {
    params.time = new Date().getTime();
    this.http.post(environment.baseUrl + 'merchant/restoreMer', params).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 禁用油站
   * @param params
   * @param callBack
   */
  public disableMer(params: any, callBack:any) {
    params.time = new Date().getTime();
    this.http.post(environment.baseUrl + 'merchant/disableMer', params).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 查询商户
   * @param merNo
   * @param callBack
   */
  public queryMer(merNo: string, callBack:any) {
    this.http.get(environment.baseUrl + 'merchant/queryMerDetail?merNo=' + merNo + '&dt=' + new Date().getTime()).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 查询商户列表
   * @param params
   * @param callBack
   */
  public queryMerList(params: any, callBack:any) {
    params.time = new Date().getTime();
    this.http.get(environment.baseUrl + 'merchant/queryMerList?' + ObjectData.objectByString(params)).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 查询商户二维码
   * @param merNo
   * @param callBack
   */
  public queryQrCodeList(merNo: any, callBack:any) {
    this.http.get(environment.baseUrl + 'merchantQrCode/queryQrCodeList?merNo='+merNo).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 编辑支付配置
   * @param merNo
   * @param callBack
   */
  public editPayConfig(param: any, callBack:any) {
    this.http.post(environment.baseUrl + 'merchantPayConfig/editConfig', param).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 查询支付配置
   * @param merNo
   * @param callBack
   */
  public queryConfig(merNo: any, callBack:any) {
    this.http.get(environment.baseUrl + 'merchantPayConfig/queryConfig?merNo='+merNo+'&dt'+new Date().getTime()).subscribe(data => {
      callBack(data);
    });
  }
}
