import { Injectable } from '@angular/core';
import {HttpClient} from "@angular/common/http";
import {environment} from "../../../environments/environment";
import {ObjectData} from "../../utils/objectData.service";

@Injectable({
  providedIn: 'root'
})
export class SpreadUserService {

  constructor(private http: HttpClient) { }

  /**
   * 冻结用户推广功能
   * @param params
   * @param callBack
   */
  public freezeUserSpread(params: any, callBack:any) {
    params.time = new Date().getTime();
    this.http.post(environment.baseUrl + 'userSpread/freezeUserSpread', params).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 解冻用户推广功能
   * @param params
   * @param callBack
   */
  public unfreezeUserSpread(params: any, callBack:any) {
    params.time = new Date().getTime();
    this.http.post(environment.baseUrl + 'userSpread/unfreezeUserSpread', params).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 充值佣金
   * @param params
   * @param callBack
   */
  public recharge(params: any, callBack:any) {
    params.time = new Date().getTime();
    this.http.post(environment.baseUrl + 'userSpread/recharge', params).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 推广用户列表
   * @param params
   * @param callBack
   */
  public getUserSpreadList(params: any, callBack:any) {
    this.http.get(environment.baseUrl + 'userSpread/getUserSpreadList?'+ObjectData.objectByString(params)).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 用户账户记录列表
   * @param params
   * @param callBack
   */
  public getRecordList(params: any, callBack:any) {
    this.http.get(environment.baseUrl + 'userSpread/getRecordList?'+ObjectData.objectByString(params)).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 统计记录金额
   * @param params
   * @param callBack
   */
  public countRecordAmount(params: any, callBack:any) {
    this.http.get(environment.baseUrl + 'userSpread/countRecordAmount?'+ObjectData.objectByString(params)).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 查询推广订单
   * @param params
   * @param callBack
   */
  public queryOilOrderSpread(params: any, callBack:any) {
    this.http.get(environment.baseUrl + 'userSpread/queryOilOrderSpread?'+ObjectData.objectByString(params)).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 统计用户账户记录佣金
   * @param params
   * @param callBack
   */
  public countAccount(params: any, callBack:any) {
    params.t = new Date().getTime()
    this.http.get(environment.baseUrl + 'userSpread/countAccount?'+ObjectData.objectByString(params)).subscribe(data => {
      callBack(data);
    });
  }


  /**
   * 用户账户详情
   * @param params
   * @param callBack
   */
  public getAccount(params: any, callBack:any) {
    params.t = new Date().getTime()
    this.http.get(environment.baseUrl + 'userSpread/getAccount?'+ObjectData.objectByString(params)).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 统计佣金情况
   * @param callBack
   */
  public countCommission(callBack:any) {
    const params = {
      t: new Date().getTime()
    };
    this.http.get(environment.baseUrl + 'userSpread/countCommission?'+ObjectData.objectByString(params)).subscribe(data => {
      callBack(data);
    });
  }
}
